package cn.sh.stc.sict.theme.hphy.controller.web;

import cn.sh.stc.sict.cloud.common.core.util.R;
import cn.sh.stc.sict.cloud.common.log.annotation.SysLog;
import cn.sh.stc.sict.cloud.common.security.util.SecurityUtils;
import cn.sh.stc.sict.cloud.upms.dto.CurrentUser;
import cn.sh.stc.sict.theme.common.crypto.EncryptionUtil;
import cn.sh.stc.sict.theme.hphy.schedule.RefreshJob;
import cn.sh.stc.sict.theme.hphy.service.HpStatisticsService;
import cn.sh.stc.sict.theme.hphy.service.HpThirdInterfaceStatusService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.AllArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.web.bind.annotation.*;

/**
 * 黄埔医导统计
 *
 * @author gao
 * @date 2023/01/06 10:43
 */
@Api(value = "[黄浦]统计使用情况", tags = "[黄浦]统计使用情况")
@RestController
@RequestMapping("hpStatistics")
@AllArgsConstructor
@Slf4j
public class HpStatisticsController {

    private final HpStatisticsService hpStatisticsService;

    private final HpThirdInterfaceStatusService hpThirdInterfaceStatusService;

    private final RefreshJob refreshJob;

    @ApiOperation("统计用户使用情况")
    @GetMapping("/usage-overview")
    public R statisticsUsage(@RequestParam("startTime") String startTime,
                             @RequestParam("endTime") String endTime) {
        log.error("统计用户使用情况：startTime = {}, token = {}", startTime, endTime);
        return new R(hpStatisticsService.getUsageOverviewStatistics(startTime, endTime));
    }

    @ApiOperation("获取公钥")
    @GetMapping("/public-key")
    public R<String> getPublicKey() {
        log.info("获取公钥");
        return new R<>(EncryptionUtil.PUBLIC_KEY);
    }

    @ApiOperation("第三方提供统计用户使用情况")
    @GetMapping("/third/usage-overview")
    @SysLog
    public R statisticsUsage4Third(@RequestParam("startTime") String startTime,
                                   @RequestParam("endTime") String endTime) {
        CurrentUser currentUser = SecurityUtils.getCurrentUser();
        log.error("统计用户使用情况：startTime = {}, token = {}, currentUser = {}", startTime, endTime, currentUser.getName());
        return new R(hpStatisticsService.countAll4Third(startTime, endTime));
    }

    @ApiOperation("更新医疗机构对接公众号状态")
    @PutMapping("/hos-org-mg-status")
    @SysLog
    public R updateHosOrgMgStatus(@RequestParam("hosOrgCode") String hosOrgCode,
                                  @RequestParam("status") Integer status) {
        hpThirdInterfaceStatusService.updateHosOrgStatus(hosOrgCode, status);
        return new R();
    }

    @ApiOperation("采集万达接口的医院、科室、患者数据")
    @PutMapping("/gather-wd")
    @SysLog
    public R gatherHosDeptDoc(@RequestParam("tag") String tag) {
        if(tag.contains("hos")){
            refreshJob.updateHosp();
        }
        if(tag.contains("dept")){
            refreshJob.updateDept();
        }
        if(tag.contains("doc")){
            refreshJob.updateDocInfo();
        }
        return new R();
    }

}
